#
# Sample program of R for reading JMA_CO2map data
# 
# After reading this program on the R console, it asks the year and month to print out and waits for key entering.
# If you put the year and month (and "Enter"),
# this program reads JMA_CO2map data in NetCDF files at the working directory, and prints out the pCO2 and CO2 flux values of the (136.5E, 29.5N) in specified month/year.
# 
# An optional package "ncdf4" is needed for using this program on R.
# It is available from CRAN site http://cran.r-project.org/ .
#
# 2014.08 Japan Meteorological Agency
# updated 27.Nov.2017

#set lon lat
lon <- 136.5
lat <- 29.5

# setting year and month
year <- as.numeric(readline("Enter year: "))
month <- as.numeric(readline("Enter month: "))

# call ncdf4
library(ncdf4)

# read NetCDF data
filename <- paste("./JMA_co2map_", year, ".nc", sep = "")
data <- nc_open(filename)
var1 <- ncvar_get(data, "pCO2s")
var2 <- ncvar_get(data, "flux")
var3 <- ncvar_get(data, "dic")
var4 <- ncvar_get(data, "ta")
var5 <- ncvar_get(data, "pH")
pCO2 <- var1[lon+0.5, lat+90.5, month]
flux <- var2[lon+0.5, lat+90.5, month]
dic <- var3[lon+0.5, lat+90.5, month]
ta <- var4[lon+0.5, lat+90.5, month]
pH <- var5[lon+0.5, lat+90.5, month]

print(paste(
"pCO2 =", round(pCO2, digits = 1), "[uatm];",
"flux =", round(flux, digits = 3), "[mol/m2/yr]",
"DIC =", round(dic, digits = 1), "[umol/kg]",
"TA =", round(ta, digits = 1), "[umol/kg]",
"pH =", round(pH, digits = 3), ""
))

# end program
